@@ -5,8 +5,10 @@
 from .keyword import scrap_keyword
 from .profile import scrap_profile
 from .topic import scrap_topic
-
+from .keyword_api import scrape_keyword_with_api
+from .profile_details import get_profile_details
 #__all__ = ["Initializer",
 #           "Utilities", "Finder",
 #           "Scraping_utilities","scrap_profile","scrap_keyword"]
-__all__ = ["scrap_profile", "scrap_keyword", "scrap_topic"]
+__all__ = ["scrap_profile", "scrap_keyword",
+           "scrap_topic", "scrape_keyword_with_api", "get_profile_details"]
